@@ -21,7 +21,11 @@
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include "gi-color-combo.h"
 #include "htmlengine-edit.h"
@@ -30,6 +34,8 @@
 #include "htmlcolor.h"
 #include "htmlcolorset.h"
 #include "htmlsettings.h"
+#include "gtkhtml-private.h"
+
 #include "body.h"
 #include "properties.h"
 #include "utils.h"
@@ -64,16 +70,16 @@ static BodyTemplate body_templates [TEMPLATES] = {
 		10,
 	},
 	{
-		N_("Perforated Paper"),
-		ICONDIR "/paper.png",
+		N_("Perforated paper"),
+		"paper.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0x3380, 0x6680},
 		30,
 	},
 	{
-		N_("Blue Ink"),
-		ICONDIR "/texture.png",
+		N_("Blue ink"),
+		"texture.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0x1fff, 0x1fff, 0x8fff},
 		{0, 0, 0, 0xffff},
@@ -81,7 +87,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
 	},
 	{
 		N_("Paper"),
-		ICONDIR "/rect.png",
+		"rect.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0, 0xffff},
@@ -89,7 +95,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Ribbon"),
-		ICONDIR "/ribbon.jpg",
+		"ribbon.jpg",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0x9900, 0x3300, 0x6600},
@@ -97,7 +103,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Midnight"),
-		ICONDIR "/midnight-stars.jpg",
+		"midnight-stars.jpg",
 		{0, 0, 0, 0},
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0xffff, 0x9900, 0},
@@ -105,7 +111,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Confidential"),
-		ICONDIR "/confidential-stamp.jpg",
+		"confidential-stamp.jpg",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0, 0xffff},
@@ -113,7 +119,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Draft"),
-		ICONDIR "/draft-stamp.jpg",
+		"draft-stamp.jpg",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0, 0xffff},
@@ -121,7 +127,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Graph paper"),
-		ICONDIR "/draft-paper.png",
+		"draft-paper.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0x8000},
 		{0, 0xe300, 0x2100, 0x2300},
@@ -160,7 +166,7 @@ entry_changed (GtkWidget *w, GtkHTMLEditBodyProperties *data)
 
 	fname = gtk_entry_get_text (GTK_ENTRY (w));
 	if (fname && *fname) {
-		gchar *file = g_strconcat ("file:", fname, NULL);
+		gchar *file = gtk_html_filename_to_uri (fname);
 
 		e->bgPixmapPtr = html_image_factory_register (e->image_factory, NULL, file, TRUE);
 		g_free (file);
@@ -172,11 +178,16 @@ static void
 changed_template (GtkWidget *w, GtkHTMLEditBodyProperties *d)
 {
 	gint template, left_margin = 10;
+	gchar *filename;
 
 	template = g_list_index (GTK_MENU_SHELL (w)->children, gtk_menu_get_active (GTK_MENU (w)));
 
+	filename = (body_templates [template].bg_pixmap ?
+		    g_build_filename (ICONDIR, body_templates [template].bg_pixmap, NULL) :
+		    g_strdup (""));
 	gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->pixmap_entry))),
-			    body_templates [template].bg_pixmap ? body_templates [template].bg_pixmap : "");
+			    filename);
+	g_free (filename);
 
 	if (template) {
 		gi_color_combo_set_color (GI_COLOR_COMBO (d->combo [2]), &body_templates [template].bg_color);
@@ -225,7 +236,6 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 {
 	GtkHTMLEditBodyProperties *data = g_new0 (GtkHTMLEditBodyProperties, 1);
 	GtkWidget *main_vbox, *hbox, *combo, *label, *t1;
-	GSList *group;
 	HTMLColor *color;
 	gint i;
 
@@ -235,32 +245,10 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	main_vbox = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
 
-	t1 = gtk_table_new (2, 2, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
-	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
-
-	data->option_template = gtk_option_menu_new ();
-	atk_object_set_name (gtk_widget_get_accessible (data->option_template), _("Template"));
-	fill_templates (data);
-	hbox = gtk_hbox_new (FALSE, 1);
-	gtk_box_pack_start (GTK_BOX (hbox), data->option_template, FALSE, FALSE, 0);
-	editor_hig_attach_row (t1, _("T_emplate:"), hbox, 0);
-	
-	/* data->entry_title = gtk_entry_new ();
-	if (gtk_html_get_title (data->cd->html)) {
-		gtk_entry_set_text (GTK_ENTRY (data->entry_title), 
-				    gtk_html_get_title (data->cd->html));
-	}
-	g_signal_connect (data->entry_title, "changed", G_CALLBACK (entry_changed), data);
-	editor_hig_attach_row (t1, _("T_itle:"), data->entry_title, 1);	*/
-
-	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("General"), t1), FALSE, FALSE, 0);
-
 	t1 = gtk_table_new (3, 2, FALSE);
 	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
 	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
 
-	group = NULL;
 	i = 0;
 #define ADD_COLOR(x, ct, g) \
         color = html_colorset_get_color (cd->html->engine->settings->color_set, ct); \
@@ -286,23 +274,32 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	data->pixmap_entry = gnome_pixmap_entry_new ("background_image", _("Background Image"), FALSE);
 	if (cd->html->engine->bgPixmapPtr) {
 		HTMLImagePointer *ip = (HTMLImagePointer *) cd->html->engine->bgPixmapPtr;
-		guint off = 0;
-		 if (!strncmp (ip->url, "file:", 5))
-			 off = 5;
-
-		 gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (data->pixmap_entry))),
-				     ip->url + off);
+		gchar *filename = gtk_html_filename_from_uri (ip->url);
+		
+		gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (data->pixmap_entry))),
+				    filename);
+		g_free (filename);
 	}
 
 
 	atk_object_set_name (gtk_widget_get_accessible (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (data->pixmap_entry))), _("Background Image File Path"));
 
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new_with_mnemonic (_("_Source:")), FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), data->pixmap_entry, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("Background Image"), hbox), FALSE, FALSE, 0);
+	t1 = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
+	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
 
-	/* gtk_idle_add (hide_preview, data); */
+	hbox = gtk_hbox_new (FALSE, 6);
+	data->option_template = gtk_option_menu_new ();
+	atk_object_set_name (gtk_widget_get_accessible (data->option_template), _("Template"));
+	fill_templates (data);
+	gtk_box_pack_start (GTK_BOX (hbox), data->option_template, FALSE, FALSE, 0);
+	editor_hig_attach_row (t1, _("T_emplate:"), hbox, 0);
+
+	hbox = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), data->pixmap_entry, TRUE, TRUE, 0);
+	editor_hig_attach_row (t1, _("C_ustom:"), hbox, 1);
+
+	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("Background Image"), t1), FALSE, FALSE, 0);
 
 	/* set ui */
 #define SET_COLOR(ct) \
