@@ -26,6 +26,7 @@
 
 #define HTML_CLUEV(x) ((HTMLClueV *)(x))
 #define HTML_CLUEV_CLASS(x) ((HTMLClueVClass *)(x))
+#define HTML_IS_CLUEV(x) (HTML_CHECK_TYPE ((x), HTML_TYPE_CLUEV))
 
 struct _HTMLClueV {
 	HTMLClue clue;
@@ -39,6 +40,10 @@ struct _HTMLClueV {
 	int border_width;
 	HTMLBorderStyle border_style;
 	HTMLColor *border_color;
+
+	HTMLColor *background_color;
+
+	HTMLDirection dir;
 };
 
 struct _HTMLClueVClass {
@@ -62,7 +67,7 @@ HTMLObject *html_cluev_new         (gint            x,
 				    gint            y,
 				    gint            percent);
 
-void        html_cluev_set_border  (HTMLClueV      *cluev,
+void        html_cluev_set_style   (HTMLClueV      *cluev,
 				    HTMLStyle      *style);
 
 #endif /* _HTMLCLUEV_H_ */
