@@ -34,6 +34,10 @@ void  html_engine_print_with_header_footer  (HTMLEngine           *e,
 					     GtkHTMLPrintCallback  header_print,
 					     GtkHTMLPrintCallback  footer_print,
 					     gpointer              user_data);
+gint  html_engine_print_get_pages_num       (HTMLEngine           *e,
+					     GnomePrintContext    *print_context,
+					     gdouble               header_height,
+					     gdouble               footer_height);
 void  html_engine_print_set_min_split_index (HTMLEngine           *e,
 					     gdouble               idx);
 #endif
