@@ -1227,7 +1227,6 @@ html_text_prepare_attrs (HTMLText *text, HTMLPainter *painter)
 		GSList *l;
 
 		for (l = text->links; l; l = l->next) {
-			PangoAttribute *attr;
 			Link *link;
 
 			link = (Link *) l->data;
@@ -1631,7 +1630,7 @@ save_open_attrs (HTMLEngineSaveState *state, GSList *attrs)
 		case PANGO_ATTR_FAMILY: {
 			PangoAttrString *family_attr = (PangoAttrString *) attr;
 
-			if (!strcasecmp (e->painter->font_manager.fixed.face
+			if (!g_ascii_strcasecmp (e->painter->font_manager.fixed.face
 					? e->painter->font_manager.fixed.face : "Monospace",
 					family_attr->value))
 				tag = "<TT>";
@@ -1695,7 +1694,7 @@ save_close_attrs (HTMLEngineSaveState *state, GSList *attrs)
 		case PANGO_ATTR_FAMILY: {
 			PangoAttrString *family_attr = (PangoAttrString *) attr;
 
-			if (!strcasecmp (e->painter->font_manager.fixed.face
+			if (!g_ascii_strcasecmp (e->painter->font_manager.fixed.face
 					? e->painter->font_manager.fixed.face : "Monospace",
 					family_attr->value))
 				tag = "</TT>";
@@ -2687,10 +2686,12 @@ offset_to_pointer_validated (const gchar *str, glong offset, gint *chars_out)
 gsize
 html_text_sanitize (const gchar **str, gint *len)
 {
+	gchar *end;
+
 	g_return_val_if_fail (str != NULL, 0);
 	g_return_val_if_fail (len != NULL, 0);
 	
-	gchar *end = offset_to_pointer_validated (*str, *len, len);
+	end = offset_to_pointer_validated (*str, *len, len);
 	if (end) {
 		return end - *str;
 	} else {
@@ -2931,9 +2932,9 @@ struct _HTMLMagicInsertMatch
 typedef struct _HTMLMagicInsertMatch HTMLMagicInsertMatch;
 
 static HTMLMagicInsertMatch mim [] = {
-	{ "(news|telnet|nttp|file|http|ftp|https)://([-a-z0-9]+(:[-a-z0-9]+)?@)?[-a-z0-9.]+[-a-z0-9](:[0-9]*)?(/[-a-z0-9_$.+!*(),;:@%&=?/~#]*[^]'.}>\\) ,?!;:\"]?)?", NULL, NULL },
-	{ "www\\.[-a-z0-9.]+[-a-z0-9](:[0-9]*)?(/[-A-Za-z0-9_$.+!*(),;:@%&=?/~#]*[^]'.}>\\) ,?!;:\"]?)?", NULL, "http://" },
-	{ "ftp\\.[-a-z0-9.]+[-a-z0-9](:[0-9]*)?(/[-A-Za-z0-9_$.+!*(),;:@%&=?/~#]*[^]'.}>\\) ,?!;:\"]?)?", NULL, "ftp://" },
+	{ "(news|telnet|nttp|file|http|ftp|sftp|https)://([-a-z0-9]+(:[-a-z0-9]+)?@)?[-a-z0-9.]+[-a-z0-9](:[0-9]*)?(([.])?/[-a-z0-9_$.+!*(),;:@%&=?/~#]*[^]'.}>\\) ,?!;:\"]?)?", NULL, NULL },
+	{ "www\\.[-a-z0-9.]+[-a-z0-9](:[0-9]*)?(([.])?/[-A-Za-z0-9_$.+!*(),;:@%&=?/~#]*[^]'.}>\\) ,?!;:\"]?)?", NULL, "http://" },
+	{ "ftp\\.[-a-z0-9.]+[-a-z0-9](:[0-9]*)?(([.])?/[-A-Za-z0-9_$.+!*(),;:@%&=?/~#]*[^]'.}>\\) ,?!;:\"]?)?", NULL, "ftp://" },
 	{ "[-_a-z0-9.'\\+]+@[-_a-z0-9.]+", NULL, "mailto:" }
 };
 
@@ -3336,8 +3337,8 @@ html_link_free (Link *link)
 gboolean
 html_link_equal (Link *l1, Link *l2)
 {
-	return l1->url && l2->url && !strcasecmp (l1->url, l2->url)
-		&& (l1->target == l2->target || (l1->target && l2->target && !strcasecmp (l1->target, l2->target)));
+	return l1->url && l2->url && !g_ascii_strcasecmp (l1->url, l2->url)
+		&& (l1->target == l2->target || (l1->target && l2->target && !g_ascii_strcasecmp (l1->target, l2->target)));
 }
 
 Link *
